'use strict';

var fs = require('fs');
var path = require('path');
var readPkgUp = require('read-pkg-up');
var arrify = require('arrify');

var appDirectory = fs.realpathSync(process.cwd());
var fromRoot = function fromRoot() {
  for (var _len = arguments.length, p = Array(_len), _key = 0; _key < _len; _key++) {
    p[_key] = arguments[_key];
  }

  return path.join.apply(path, [appDirectory].concat(p));
};

var getPkgProp = function getPkgProp(prop) {
  return readPkgUp.sync({ cwd: process.cwd() }).pkg[prop];
};
var hasPkgProp = function hasPkgProp(pkgProp, props) {
  return arrify(props).some(function (prop) {
    return (getPkgProp(pkgProp) || {}).hasOwnProperty(prop);
  });
};
var ifPkgProp = function ifPkgProp(pkgProp, props, t, f) {
  return hasPkgProp(pkgProp, props) ? t : f;
};

var hasPeerDep = hasPkgProp.bind(null, 'peerDependencies');
var hasDep = hasPkgProp.bind(null, 'dependencies');
var hasDevDep = hasPkgProp.bind(null, 'devDependencies');
var hasAnyDep = function hasAnyDep() {
  for (var _len2 = arguments.length, args = Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
    args[_key2] = arguments[_key2];
  }

  return [hasDep, hasDevDep, hasPeerDep].some(function (fn) {
    return fn.apply(undefined, args);
  });
};

var ifPeerDep = ifPkgProp.bind(null, 'peerDependencies');
var ifDep = ifPkgProp.bind(null, 'dependencies');
var ifDevDep = ifPkgProp.bind(null, 'devDependencies');
var ifAnyDep = function ifAnyDep(deps, t, f) {
  return hasAnyDep(deps) ? t : f;
};

var ifScript = ifPkgProp.bind(null, 'scripts');

function ifConfig(type, defaultConfig) {
  var configPath = path.resolve(path.join(appDirectory, '/kcd.config.js'));
  if (fs.existsSync(configPath)) {
    return require(configPath)[type] || defaultConfig;
  } else {
    return {};
  }
}

module.exports = {
  ifDevDep,
  ifPeerDep,
  ifScript,
  ifDep,
  ifAnyDep,
  ifConfig,
  hasPkgProp,
  appDirectory,
  fromRoot
};